==> otf2_3.0.3.orig.tar.xz: otf2-3.0.3/templates/templates.py <==
common_template_deps = [
    'share/otf2/otf2.types',
    'share/otf2/otf2.enums',
    'share/otf2/otf2.defs',
    'share/otf2/otf2.events',
    'share/otf2/otf2.snaps'
]

templates = [
    [ 'include/otf2/OTF2_GeneralDefinitions.h',
        'OTF2_GeneralDefinitions.tmpl.h',
        'build-config/VERSION' ],
    [ 'include/otf2/OTF2_Definitions.h',
        'OTF2_Definitions.tmpl.h' ],
    [ 'src/otf2_file_types.h',
        'otf2_file_types.tmpl.h' ],
    [ 'include/otf2/OTF2_Events.h',
        'OTF2_Events.tmpl.h' ],
    [ 'src/otf2_events_int.h',
        'otf2_events_int.tmpl.h' ],
    [ 'include/otf2/OTF2_EvtReaderCallbacks.h',
        'OTF2_EvtReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_EvtReader_inc.c',
        'OTF2_EvtReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_EvtWriter.h',
        'OTF2_EvtWriter.tmpl.h' ],
    [ 'src/OTF2_EvtWriter_inc.c',
        'OTF2_EvtWriter_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_GlobalEvtReaderCallbacks.h',
        'OTF2_GlobalEvtReaderCallbacks.tmpl.h' ],
    [ 'include/otf2/OTF2_GlobalSnapReaderCallbacks.h',
        'OTF2_GlobalSnapReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_GlobalEvtReader_inc.c',
        'OTF2_GlobalEvtReader_inc.tmpl.c' ],
    [ 'src/OTF2_GlobalSnapReader_inc.c',
        'OTF2_GlobalSnapReader_inc.tmpl.c' ],
    [ 'src/otf2_local_definitions.h',
        'otf2_local_definitions.tmpl.h' ],
    [ 'include/otf2/OTF2_DefReaderCallbacks.h',
        'OTF2_DefReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_DefReader_inc.c',
        'OTF2_DefReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_DefWriter.h',
        'OTF2_DefWriter.tmpl.h' ],
    [ 'src/OTF2_DefWriter_inc.c',
        'OTF2_DefWriter_inc.tmpl.c' ],
    [ 'src/otf2_global_definitions.h',
        'otf2_global_definitions.tmpl.h' ],
    [ 'include/otf2/OTF2_GlobalDefReaderCallbacks.h',
        'OTF2_GlobalDefReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_GlobalDefReader_inc.c',
        'OTF2_GlobalDefReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_GlobalDefWriter.h',
        'OTF2_GlobalDefWriter.tmpl.h' ],
    [ 'src/OTF2_GlobalDefWriter_inc.c',
        'OTF2_GlobalDefWriter_inc.tmpl.c' ],
    [ 'src/otf2_snaps.h',
        'otf2_snaps.tmpl.h' ],
    [ 'include/otf2/OTF2_SnapReaderCallbacks.h',
        'OTF2_SnapReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_SnapReader_inc.c',
        'OTF2_SnapReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_SnapWriter.h',
        'OTF2_SnapWriter.tmpl.h' ],
    [ 'src/OTF2_SnapWriter_inc.c',
        'OTF2_SnapWriter_inc.tmpl.c' ],
    [ 'src/tools/otf2_print/otf2_print_inc.c',
        'otf2_print_inc.tmpl.c' ],
    [ 'src/tools/otf2_print/otf2_print_types.h',
        'otf2_print_types.tmpl.h' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_events.hpp',
        'otf2_snapshots_events.tmpl.hpp' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_events_inc.cpp',
        'otf2_snapshots_events_inc.tmpl.cpp' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_callbacks_inc.cpp',
        'otf2_snapshots_callbacks_inc.tmpl.cpp' ],
    [ 'src/otf2_attribute_value_inc.c',
        'otf2_attribute_value_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_AttributeValue.h',
        'OTF2_AttributeValue.tmpl.h' ],
    [ 'src/otf2_attribute_list_inc.c',
        'otf2_attribute_list_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_AttributeList.h',
        'OTF2_AttributeList.tmpl.h' ],
    [ 'src/otf2_attic_types.h',
        'otf2_attic_types.tmpl.h' ],
    [ 'doc/doxygen-user/definitions.dox',
        'definitions.tmpl.dox' ],
    [ 'doc/doxygen-user/events.dox',
        'events.tmpl.dox' ],
    [ 'doc/doxygen-user/snaps.dox',
        'snaps.tmpl.dox' ],
    [ 'templates/example.cc',
        'example.tmpl.cc' ],
    [ 'include/otf2/OTF2_EventSizeEstimator.h',
        'OTF2_EventSizeEstimator.tmpl.h' ],
    [ 'src/OTF2_EventSizeEstimator.c',
        'OTF2_EventSizeEstimator.tmpl.c' ],
    [ 'src/tools/otf2_estimator/otf2_estimator_inc.cpp',
        'otf2_estimator_inc.tmpl.cpp' ],
    # python bindings
    [ 'src/python/_otf2/Definitions.py',
            '_otf2.Definitions.tmpl.py' ],
    [ 'src/python/_otf2/Events.py',
            '_otf2.Events.tmpl.py' ],
    [ 'src/python/_otf2/GeneralDefinitions.py',
            '_otf2.GeneralDefinitions.tmpl.py', ],
    [ 'src/python/_otf2/GlobalDefReaderCallbacks.py',
            '_otf2.GlobalDefReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/DefReaderCallbacks.py',
            '_otf2.DefReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/EvtReaderCallbacks.py',
            '_otf2.EvtReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/GlobalEvtReaderCallbacks.py',
            '_otf2.GlobalEvtReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/GlobalSnapReaderCallbacks.py',
            '_otf2.GlobalSnapReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/SnapReaderCallbacks.py',
            '_otf2.SnapReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/EvtWriter.py',
            '_otf2.EvtWriter.tmpl.py' ],
    [ 'src/python/_otf2/DefWriter.py',
            '_otf2.DefWriter.tmpl.py' ],
    [ 'src/python/_otf2/GlobalDefWriter.py',
            '_otf2.GlobalDefWriter.tmpl.py' ],
    [ 'src/python/_otf2/SnapWriter.py',
            '_otf2.SnapWriter.tmpl.py' ],
    [ 'src/python/_otf2/AttributeList.py',
            '_otf2.AttributeList.tmpl.py' ],
    [ 'src/python/_otf2/EventSizeEstimator.py',
            '_otf2.EventSizeEstimator.tmpl.py' ],
    [ 'src/python/_otf2/AttributeValue.py',
            '_otf2.AttributeValue.tmpl.py' ],
    [ 'src/python/otf2/events.py',
            'otf2.events.tmpl.py' ],
    [ 'src/python/otf2/event_reader.py',
            'otf2.event_reader.tmpl.py' ],
    [ 'src/python/otf2/event_writer.py',
            'otf2.event_writer.tmpl.py' ],
    [ 'src/python/otf2/registry.py',
            'otf2.registry.tmpl.py' ],
    [ 'src/python/otf2/definition_writer.py',
            'otf2.definition_writer.tmpl.py' ],
    [ 'src/python/otf2/enums.py',
            'otf2.enums.tmpl.py' ],
    [ 'src/python/otf2/attribute_value.py',
            'otf2.attribute_value.tmpl.py' ],
]

==> otf2_3.1.1.orig.tar.xz: otf2-3.1.1/templates/templates.py <==
common_template_deps = [
    'share/otf2/otf2.types',
    'share/otf2/otf2.enums',
    'share/otf2/otf2.defs',
    'share/otf2/otf2.events',
    'share/otf2/otf2.snaps'
]

templates = [
    [ 'include/otf2/OTF2_GeneralDefinitions.h',
        'OTF2_GeneralDefinitions.tmpl.h',
        'build-config/VERSION' ],
    [ 'include/otf2/OTF2_Definitions.h',
        'OTF2_Definitions.tmpl.h' ],
    [ 'src/otf2_file_types.h',
        'otf2_file_types.tmpl.h' ],
    [ 'include/otf2/OTF2_Events.h',
        'OTF2_Events.tmpl.h' ],
    [ 'src/otf2_events_int.h',
        'otf2_events_int.tmpl.h' ],
    [ 'include/otf2/OTF2_EvtReaderCallbacks.h',
        'OTF2_EvtReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_EvtReader_inc.c',
        'OTF2_EvtReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_EvtWriter.h',
        'OTF2_EvtWriter.tmpl.h' ],
    [ 'src/OTF2_EvtWriter_inc.c',
        'OTF2_EvtWriter_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_GlobalEvtReaderCallbacks.h',
        'OTF2_GlobalEvtReaderCallbacks.tmpl.h' ],
    [ 'include/otf2/OTF2_GlobalSnapReaderCallbacks.h',
        'OTF2_GlobalSnapReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_GlobalEvtReader_inc.c',
        'OTF2_GlobalEvtReader_inc.tmpl.c' ],
    [ 'src/OTF2_GlobalSnapReader_inc.c',
        'OTF2_GlobalSnapReader_inc.tmpl.c' ],
    [ 'src/otf2_local_definitions.h',
        'otf2_local_definitions.tmpl.h' ],
    [ 'include/otf2/OTF2_DefReaderCallbacks.h',
        'OTF2_DefReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_DefReader_inc.c',
        'OTF2_DefReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_DefWriter.h',
        'OTF2_DefWriter.tmpl.h' ],
    [ 'src/OTF2_DefWriter_inc.c',
        'OTF2_DefWriter_inc.tmpl.c' ],
    [ 'src/otf2_global_definitions.h',
        'otf2_global_definitions.tmpl.h' ],
    [ 'include/otf2/OTF2_GlobalDefReaderCallbacks.h',
        'OTF2_GlobalDefReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_GlobalDefReader_inc.c',
        'OTF2_GlobalDefReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_GlobalDefWriter.h',
        'OTF2_GlobalDefWriter.tmpl.h' ],
    [ 'src/OTF2_GlobalDefWriter_inc.c',
        'OTF2_GlobalDefWriter_inc.tmpl.c' ],
    [ 'src/otf2_snaps.h',
        'otf2_snaps.tmpl.h' ],
    [ 'include/otf2/OTF2_SnapReaderCallbacks.h',
        'OTF2_SnapReaderCallbacks.tmpl.h' ],
    [ 'src/OTF2_SnapReader_inc.c',
        'OTF2_SnapReader_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_SnapWriter.h',
        'OTF2_SnapWriter.tmpl.h' ],
    [ 'src/OTF2_SnapWriter_inc.c',
        'OTF2_SnapWriter_inc.tmpl.c' ],
    [ 'src/tools/otf2_print/otf2_print_inc.c',
        'otf2_print_inc.tmpl.c' ],
    [ 'src/tools/otf2_print/otf2_print_types.h',
        'otf2_print_types.tmpl.h' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_events.hpp',
        'otf2_snapshots_events.tmpl.hpp' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_events_inc.cpp',
        'otf2_snapshots_events_inc.tmpl.cpp' ],
    [ 'src/tools/otf2_snapshots/otf2_snapshots_callbacks_inc.cpp',
        'otf2_snapshots_callbacks_inc.tmpl.cpp' ],
    [ 'src/otf2_attribute_value_inc.c',
        'otf2_attribute_value_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_AttributeValue.h',
        'OTF2_AttributeValue.tmpl.h' ],
    [ 'src/otf2_attribute_list_inc.c',
        'otf2_attribute_list_inc.tmpl.c' ],
    [ 'include/otf2/OTF2_AttributeList.h',
        'OTF2_AttributeList.tmpl.h' ],
    [ 'src/otf2_attic_types.h',
        'otf2_attic_types.tmpl.h' ],
    [ 'doc/doxygen-user/definitions.dox',
        'definitions.tmpl.dox' ],
    [ 'doc/doxygen-user/events.dox',
        'events.tmpl.dox' ],
    [ 'doc/doxygen-user/snaps.dox',
        'snaps.tmpl.dox' ],
    [ 'templates/example.cc',
        'example.tmpl.cc' ],
    [ 'include/otf2/OTF2_EventSizeEstimator.h',
        'OTF2_EventSizeEstimator.tmpl.h' ],
    [ 'src/OTF2_EventSizeEstimator.c',
        'OTF2_EventSizeEstimator.tmpl.c' ],
    [ 'src/tools/otf2_estimator/otf2_estimator_inc.cpp',
        'otf2_estimator_inc.tmpl.cpp' ],
    # python bindings
    [ 'src/python/_otf2/Definitions.py',
            '_otf2.Definitions.tmpl.py' ],
    [ 'src/python/_otf2/Events.py',
            '_otf2.Events.tmpl.py' ],
    [ 'src/python/_otf2/GeneralDefinitions.py',
            '_otf2.GeneralDefinitions.tmpl.py', ],
    [ 'src/python/_otf2/GlobalDefReaderCallbacks.py',
            '_otf2.GlobalDefReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/DefReaderCallbacks.py',
            '_otf2.DefReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/EvtReaderCallbacks.py',
            '_otf2.EvtReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/GlobalEvtReaderCallbacks.py',
            '_otf2.GlobalEvtReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/GlobalSnapReaderCallbacks.py',
            '_otf2.GlobalSnapReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/SnapReaderCallbacks.py',
            '_otf2.SnapReaderCallbacks.tmpl.py' ],
    [ 'src/python/_otf2/EvtWriter.py',
            '_otf2.EvtWriter.tmpl.py' ],
    [ 'src/python/_otf2/DefWriter.py',
            '_otf2.DefWriter.tmpl.py' ],
    [ 'src/python/_otf2/GlobalDefWriter.py',
            '_otf2.GlobalDefWriter.tmpl.py' ],
    [ 'src/python/_otf2/SnapWriter.py',
            '_otf2.SnapWriter.tmpl.py' ],
    [ 'src/python/_otf2/AttributeList.py',
            '_otf2.AttributeList.tmpl.py' ],
    [ 'src/python/_otf2/EventSizeEstimator.py',
            '_otf2.EventSizeEstimator.tmpl.py' ],
    [ 'src/python/_otf2/AttributeValue.py',
            '_otf2.AttributeValue.tmpl.py' ],
    [ 'src/python/otf2/events.py',
            'otf2.events.tmpl.py' ],
    [ 'src/python/otf2/event_reader.py',
            'otf2.event_reader.tmpl.py' ],
    [ 'src/python/otf2/event_writer.py',
            'otf2.event_writer.tmpl.py' ],
    [ 'src/python/otf2/registry.py',
            'otf2.registry.tmpl.py' ],
    [ 'src/python/otf2/definition_writer.py',
            'otf2.definition_writer.tmpl.py' ],
    [ 'src/python/otf2/enums.py',
            'otf2.enums.tmpl.py' ],
    [ 'src/python/otf2/attribute_value.py',
            'otf2.attribute_value.tmpl.py' ],
    [ 'contrib/CMakeLists.txt',
        'contrib-CMakeLists.tmpl.txt',
        'build-config/VERSION' ],
    [ 'contrib/config-backend.h',
        'contrib-config-backend.tmpl.h',
        'build-config/VERSION' ],
]
